// Filename: FlatEarth_V4_0980.sc
// Author : JackDole 2018.04.29 13:30:05
//  Edition : Quarior 2018.05.02 18:12:00

// daysYear     365.24218985
// AU           149597870.700
// eMass        5.9736e24
// pi           3.14159265358979323846
// Golden ratio 1.6180339887498948

//------------------------------------------------------------------------------

Barycenter "TinySol-FlatEarth"
{
    ParentBody  "JDV 00034"
    
    Obliquity       90
    EqAscendNode    0.0
    
    StaticPosPolar      (180.0 90.0 1000.0)
}

Star "Tiny Sol"
{
    ParentBody  "TinySol-FlatEarth"
    Class       "G2 V"

    Radius      20
	Mass		 0.0002762
	//Gravity		28.088 // g
    
    Oblateness  0.0
    AbsMagn     25.5
	TidalLocked true

    Albedo      0.99
    Brightness  9.761905
    Color       (0.954 0.920 0.000)
    
    Orbit
    {
        SemiMajorAxis   6.6845871222684e-05
        Period          0.0027304131844069    // 1-1/365.24218985
        Eccentricity    0.0
        Inclination     -90
        AscendingNode   0
        ArgOfPericenter 0
        MeanAnomaly     0
        RefPlane        "Equator"
    }
}

DwarfMoon "Tiny Moon"
{
    ParentBody  "JDV 00034"
    Class       "Selena"
         
    Radius      20
	Mass		1.6302e-6
	//Gravity		0.16579 // g
    
    InertiaMoment   0.3974729
	TidalLocked	true

    Obliquity       120
    EqAscendNode    0

    Albedo      0.3
    Brightness  5
    Color       (0.398 0.341 0.297)

    Surface
    {
        // Surface map author: John van Vliet
        DiffMap        "Moon/Surface-JVV"
        DiffTileSize    258
        DiffTileBorder  1

        // Elevation map author: Vladimir Romanyuk "SpaceEngineer"
        BumpMap        "Moon/Bump-SE"
        BumpTileSize    258
        BumpTileBorder  1
        BumpHeight      0.19851
        BumpOffset      0.09058

        Hapke           1.0
    }
    
    Orbit
    {
        SemiMajorAxis   4.9556855089649e-05
        Period          0.0026401268557768        // 1-1/28
        Eccentricity    0.0
        Inclination     -90
        AscendingNode   0
        ArgOfPericenter 180
        MeanAnomaly     0
        RefPlane        "Equator"
    }
}

Planet "Flat Earth III"
{
    ParentBody  "TinySol-FlatEarth"
    Class       "Terra"
    
    Radius      12756.28

    //Oblateness  0.999       // Flat earth
    Oblateness  0.75         // Konvex earth

    Age         4.54

    RotationPeriod  1e12
    Obliquity       90
    EqAscendNode    0.0

    Color       ( 0.850 0.850 1.000 )
    Albedo      0.367

    Brightness      1.4

    Life
    {
        Class   "Organic"
        Type    "Multicellular"
        Biome   "Marine/Terrestrial"
    }
    
    Surface
    {
        DiffMap        "FlatEarth/RF-Surface_1K.*"
        DiffTileSize    514
        DiffTileBorder  1
        DiffMapAlpha   "Water"
        
        BumpMap        "FlatEarth/RF-Bumpmap_1K.*"
        BumpTileSize    514
        BumpTileBorder  1
        BumpHeight      19.475
        BumpOffset      10.896
        
        SpecBrightIce   0.0
        SpecBrightWater 0.35
        colorSea       (0.04 0.10 0.20 1.00)
        colorShelf     (0.15 0.48 0.46 1.00)
    }
    
    Clouds
    {
        Height          10.33301
        BumpHeight      6.770232
        DayAmbient      2
        Lommel          0.2
        Exposure        2
        Color          (1.000 1.000 1.000 1.000)
        mainFreq        0.8809524
        mainOctaves     7
        Coverage        0.25
        twistZones      3.135306
        twistMagn       0
    }

    Clouds
    {
        Height          12.94629
        BumpHeight      5.013498
        DayAmbient      2
        Lommel          0.2
        Exposure        2
        Color          (1.000 1.000 1.000 1.000)
        mainFreq        0.8809524
        mainOctaves     7
        Coverage        0.25
        twistZones      3.135306
        twistMagn       0
    }

    Clouds
    {
        Height          15.56055
        BumpHeight      6.029501
        DayAmbient      2
        Lommel          0.2
        Exposure        2
        Color          (1.000 1.000 1.000 1.000)
        mainFreq        0.8809524
        mainOctaves     7
        Coverage        0.25
        twistZones      3.135306
        twistMagn       0
    }
    
    Ocean
    {
        Height          0       //-0.0004844666
        Hapke           0
        SpotBright      2
        SpotWidth       0.15
        DayAmbient      2
    }
    
    Atmosphere
    {
        Model          "Earth"
        Height          68
        Density         1
        Pressure        1
        Greenhouse      37
        Bright          4.0
        Opacity         0
        SkyLight        5
        
        Composition
        {
            N2  77.7729
            O2  20.8625
            Ar  0.9303
            H2O 0.4000
            CO2 0.0398
            Ne  0.00182
            He  0.00046
            CH4 0.00017
            Kr  0.000114
            H2  0.00005
            Xe  0.0000087
        }
    }
    
    NoAurora    true
    NoRings     true
    
    StaticPosPolar      (0.0 0.0 -3500.0)
}

Asteroid "Heaven"
{
    ParentBody  "Flat Earth III"
    Class       "Terra"
    
    Radius      12756.28
    Oblateness  0.25
    
    RotationPeriod  -24
    Obliquity       0.0
    EqAscendNode    0.0

    Surface
    {
        DiffMap        "FlatEarth/Invisible.*"
        DiffMapAlpha    "Transp"
    }
    
    Clouds
    {
        Height         10
        DiffMap        "FlatEarth/Glocke.*"
        DiffMapAlpha    "Transp"
        
        GlowMap        "FlatEarth/GlockeGlow.*"
        GlowMode       "Permanent"
        GlowColor      (1.00 0.90 0.66)
        GlowBright      2.5
        
        Velocity        0
    }
    
    NoOcean         true
    NoAurora        true
    NoAtmosphere    true
    NoRings         true
    
    StaticPosPolar      (0.0 0.0 0.0)
}

//------------------------------------------------------------------------------
